+ Proxmox Datacenter Manager is currently under development and not yet production ready.
+ The role-based permission management, combined with the integration of multiple external
+ authentication sources provides the basis for a secure and stable environment.
+
+
+
+
+
+
+
+
+
+
+ Commitment to Free Software
+ The source code is released under the GNU Affero General Public License, v3.
+
+
+
+
+
+
+ RESTful web API
+ The resource-oriented architecture (ROA) and declarative API definition using JSON
+ Schema enable easy integration for third party management tools.
+
+
+
+
+
+
+ Independent
+ There is no dependency between Proxmox Datacenter Manager and the resources it manages,
+ any Proxmox VE cluster stays fully self-contained.
+
+ Proxmox Datacenter Manager helps you manage and gain visibility into your mission-critical
+ resources.
+
+
+
+
+
+
+
+
+
+ Support for Proxmox VE
+ The Proxmox Virtual Environment will be fully supported, and the seamless integration
+ allows you to easily manage VMs and containers.
+
+
+
+
+
+
+ Web Console
+ SSL-secured, browser-integrated system console.
+
+
+
+
+
+
+ Flaky connection? No Problem.
+ Using only the API to access resources eliminates the need for highly stable,
+ low-latency network connections.
+
The Proxmox Installer
+ automatically partitions your hard disk. It installs all required packages and makes the
+ system bootable from the hard disk.
+ All existing partitions and data on the selected disks will be lost.
+
+ To continue the installation, press the Next button.
+
+
+
+
+
+
+
+
+
Please verify the installation target
+ The displayed hard disk will be used for the installation.
+ Warning: All existing partitions and data on selected disks will be lost.
+
+
+
+
+
+
Automatic hardware detection
+ The installer automatically configures your hardware.
+
+
+
+
+
+
Graphical user interface
+ Final configuration will be done on the graphical user interface, via a web browser.
+
Proxmox Datacenter Manager is a
+ full-featured, highly secure system, based on Debian GNU/Linux.
+
+ In this step, please provide the root password.
+
+
+
+
+
+
+
+
Password:
+ Please use a strong password. It should be at least 8 characters long,
+ and contain a combination of letters, numbers, and symbols.
+
+
+
+
+
+
Email:
+ Enter a valid email address. Your Proxmox Datacenter Manager will send
+ important alert notifications to this email account (all emails for 'root').
+
+
+
+
+
+
To continue the installation, press the Next button.
+
+
+
+
+
+
+
diff --git a/proxmox-installer-common/src/setup.rs b/proxmox-installer-common/src/setup.rs
index 0ef47d2..6cc3804 100644
--- a/proxmox-installer-common/src/setup.rs
+++ b/proxmox-installer-common/src/setup.rs
@@ -26,6 +26,7 @@ pub enum ProxmoxProduct {
PVE,
PBS,
PMG,
+ PDM,
}
impl ProxmoxProduct {
@@ -34,6 +35,7 @@ impl ProxmoxProduct {
Self::PVE => "pve",
Self::PMG => "pmg",
Self::PBS => "pbs",
+ Self::PDM => "pdm",
}
}
}
@@ -44,6 +46,7 @@ impl fmt::Display for ProxmoxProduct {
Self::PVE => "pve",
Self::PMG => "pmg",
Self::PBS => "pbs",
+ Self::PDM => "pdm",
})
}
}
diff --git a/test/zfs-arc-max.pl b/test/zfs-arc-max.pl
index 74cb9b5..c0938f4 100755
--- a/test/zfs-arc-max.pl
+++ b/test/zfs-arc-max.pl
@@ -51,6 +51,10 @@ while (my ($total_mem, $expected) = each %default_tests) {
mock_product('pmg');
is(Proxmox::Install::RunEnv::default_zfs_arc_max(), 0,
"zfs_arc_max should default to `0` for PMG with $total_mem MiB system memory");
+
+ mock_product('pdm');
+ is(Proxmox::Install::RunEnv::default_zfs_arc_max(), 0,
+ "zfs_arc_max should default to `0` for PDM with $total_mem MiB system memory");
}
my @clamp_tests = (
diff --git a/proxmox-installer-common/src/options.rs b/proxmox-installer-common/src/options.rs
index 9720804..0fd3e43 100644
--- a/proxmox-installer-common/src/options.rs
+++ b/proxmox-installer-common/src/options.rs
@@ -465,7 +465,7 @@ impl NetworkOptions {
Fqdn::from(&format!("{hostname}.{domain}")).unwrap_or_else(|_| {
// Safety: This will always result in a valid FQDN, as we control & know
// the values of default_hostname (one of "pve", "pmg" or "pbs") and
// constant-defined DEFAULT_DOMAIN.
Fqdn::from(&format!("{}.{}", default_hostname, Self::DEFAULT_DOMAIN)).unwrap()
})
@@ -517,6 +517,7 @@ mod tests {
);
assert_eq!(default_zfs_arc_max(ProxmoxProduct::PBS, *total_memory), 0);
assert_eq!(default_zfs_arc_max(ProxmoxProduct::PMG, *total_memory), 0);
+ assert_eq!(default_zfs_arc_max(ProxmoxProduct::PDM, *total_memory), 0);
}
}
}
@@ -465,7 +465,7 @@ impl NetworkOptions {
Fqdn::from(&format!("{hostname}.{domain}")).unwrap_or_else(|_| {
// Safety: This will always result in a valid FQDN, as we control & know
- // the values of default_hostname (one of "pve", "pmg" or "pbs") and
+ // the values of default_hostname (one of "pve", "pmg", "pbs" or "pdm") and
// constant-defined DEFAULT_DOMAIN.
Fqdn::from(&format!("{}.{}", default_hostname, Self::DEFAULT_DOMAIN)).unwrap()
diff --git a/proxmox-post-hook/src/main.rs b/proxmox-post-hook/src/main.rs
index 08a2b90..d029b04 100644
--- a/proxmox-post-hook/src/main.rs
+++ b/proxmox-post-hook/src/main.rs
@@ -168,8 +168,8 @@ struct PostHookInfo {
schema: PostHookInfoSchema,
/// major.minor version of Debian as installed, retrieved from /etc/debian_version
debian_version: String,
/// PVE/PMG/PBS version as reported by `pveversion`, `pmgversion` or
/// `proxmox-backup-manager version`, respectively.
product: ProductInfo,
/// Release information for the ISO used for the installation.
iso: IsoInfo,
@@ -399,6 +399,7 @@ impl PostHookInfo {
ProxmoxProduct::PVE => "pve-manager",
ProxmoxProduct::PMG => "pmg-api",
ProxmoxProduct::PBS => "proxmox-backup-server",
+ ProxmoxProduct::PDM => "proxmox-datacenter-manager",
};
let version = run_cmd(&[
@@ -168,8 +168,8 @@ struct PostHookInfo {
/// major.minor version of Debian as installed, retrieved from /etc/debian_version
debian_version: String,
- /// PVE/PMG/PBS version as reported by `pveversion`, `pmgversion` or
- /// `proxmox-backup-manager version`, respectively.
+ /// PVE/PMG/PBS/PDM version as reported by `pveversion`, `pmgversion`,
+ /// `proxmox-backup-manager version` or `proxmox-datacenter-manager version`, respectively.
product: ProductInfo,
/// Release information for the ISO used for the installation.